from setuptools import setup

setup(name='derek_test_distributions',
      version='0.1',
      description='Binomial and Gaussian distributions',
      packages=['derek_test_distributions'],
      author = 'Derek Chen',
      zip_safe=False)
